#############################################################
## move_to_zero.praat
## 
## This script loops through all TextGrid files in a directory.
## For each file, it moves all boundaries on a given tier to
## zero-crossings in the corresponding wav file (Channel 1).
## Retains all original interval labels.
## 
## jessamyn.schertz@utoronto.ca
## July 2020
#############################################################

beginPause: "User Input"
	comment: "Directory containing original TGs and wav files"
	word: "dataDir", "data/"
	comment: "Directory in which to save new TGs"
	comment: "(if this is the same as above, will overwrite original TGs)"
	word: "newDir", "new_tgs/"
	comment: "Tier number to be modified"
	positive: "tierNum", 1
clicked = endPause: "Continue", 1

segTier = 1

files = Create Strings as file list: "", dataDir$+"*.TextGrid"
numFiles = Get number of strings

for file from 1 to numFiles
	select files
	filename$ = Get string: file
	filename$ = filename$-".TextGrid"

	sound = Read from file: dataDir$+filename$+".wav"
	tg = Read from file: dataDir$+filename$+".TextGrid"

	numInt = Get number of intervals: segTier

	# move all boundaries to nearest zero-crossing
	for int from 2 to numInt
		start = Get start point: segTier, int
		label$ = Get label of interval: segTier, int
		Set interval text: segTier, int, ""

		# now remove boundary, find zero-crossing,
		# replace boundary and replace text.

		Remove left boundary: segTier, int

		select sound
		zeroTime = Get nearest zero crossing: 1, start

		select tg
		Insert boundary: segTier, zeroTime
		Set interval text: segTier, int, label$	
	endfor

	Save as text file: newDir$+filename$+".TextGrid"

	select sound
	plus tg
	Remove
endfor

